function [ surf ] = EvalKrigSurf( id, Xnew)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% EvalKrigSurf:
% This function evaluates the Krigifier surfaces that were constructed
% using the MakeKrigSurf.m function. 
%
% Author: Erin Leatherman, West Virginia University
%
% Questions/Comments: 
% Please email Erin Leatherman at erleatherman@mail.wvu.edu.
%
% Copyright 2016. Erin Leatherman, West Virginia University.
%
% THERE IS NO WARRANTY, EXPRESS OR IMPLIED. WE DO NOT ASSUME ANY LIABILITY
% FOR THE USE OF THIS SOFTWARE.  If software is modified to produce
% derivative works, such modified software should be clearly marked.
% Additionally, this program is free software; you can redistribute it 
% and/or modify it under the terms of the GNU General Public License as 
% published by the Free Software Foundation; version 2.0 of the License. 
% Accordingly, this program is distributed in the hope that it will be 
% useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
% of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
% General Public License for more details.
%
% For function details and reference information, see:
% http://stat.wvu.edu/~erl/CompExpDesgs_Pred/TestSurfaces/
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS:
% id = character string to identify which set of Krigifier surfaces is to
%   be evaluated.  This string should match the `id' string used to
%   construct the surfaces using the MakeKrigSurf.m function. 
% Xnew = m x d matrix of inputs at which you want to evaluate the
%   Krigifier, where
%   m = number of observations to be taken,
%   d = number of input dimensions (this should match d used to
%       construct the surfaces using the MakeKrigSurf.m function) 
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUT: 
% surf = (m x nsurf) matrix of Krigifier surface values, where
%   m = number of observations to be taken,
%   nsurf = number of Krigifier surfaces specified when construct the 
%       surfaces using the MakeKrigSurf.m function 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% load the .mat file containing the Krigifier construction information
tmp=load(id);

% check to make sure the number of dimensions of Xnew corresponds to the
% number of dimensions used to construct the Krigifier surfaces
if tmp.d~=size(Xnew,2)
    str=sprintf(strcat('*** Warning: The number of inputs for Xnew does',...
    ' not match the \nnumber of dimensions used to construct the',...
    ' Krigifier surfaces! \nThe surfaces will not be evaluated. ***'));
    disp(str);
else


% grab the training values that are common for each of the surfaces
Xtrain=tmp.x;       %training design
mt=tmp.n;  %number of training draws
[it, in]=meshgrid(1:size(Xtrain,1), 1:size(Xnew,1)); % used to calc correlations
dsq=4*(Xtrain(it,:)-Xnew(in,:)).^2;     % exponent for correlations

% initialize storage
surf = NaN(size(Xnew,1),tmp.nsurf);

% evaluate all nsurf surfaces in turn
for ii=1:tmp.nsurf
    
    % grab the training data and correlation information
    Ytrain=tmp.Y(:,ii);
    R=tmp.R(:,:,ii);
    rho=tmp.rho(ii,:);
    
    % calculate BLUP
    betahat=(ones(1,mt)*(R\ones(mt,1)))\(ones(1,mt)*(R\Ytrain));

    % create r' (correlations between training design and points a which we
    % want to take surface evaluations)
    rp=reshape(prod(bsxfun(@power,rho,dsq),2),size(Xnew,1),mt);

    % put everything together
    surf(:,ii)=betahat*ones(size(Xnew,1),1) + rp*(R\(Ytrain-ones(mt,1)*betahat));
   
    clear Ytrain R rho betahat rp

end





end

