function [  ] = MakeKrigSurf(nsurf, d, mu, sig2, rho, id)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MakeKrigSurf:
% This function constructs Krigifier surfaces to be used as test bed
% functions.
%
% Author: Erin Leatherman, West Virginia University
%
% Questions/Comments: 
% Please email Erin Leatherman at erleatherman@mail.wvu.edu.
%
% Copyright 2016. Erin Leatherman, West Virginia University.
%
% THERE IS NO WARRANTY, EXPRESS OR IMPLIED. WE DO NOT ASSUME ANY LIABILITY
% FOR THE USE OF THIS SOFTWARE.  If software is modified to produce
% derivative works, such modified software should be clearly marked.
% Additionally, this program is free software; you can redistribute it 
% and/or modify it under the terms of the GNU General Public License as 
% published by the Free Software Foundation; version 2.0 of the License. 
% Accordingly, this program is distributed in the hope that it will be 
% useful, but WITHOUT ANY WARRANTY; without even the implied warranty 
% of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
% General Public License for more details.
%
% For function details and reference information, see:
% http://stat.wvu.edu/~erl/CompExpDesgs_Pred/TestSurfaces/
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INPUTS:
% nsurf = number of surfaces to be constructed
% d = number of input dimensions
% mu = mean of the Krigifier        
% sig2 = variance of the Krigifier
% rho = nsurf x d matrix of correlation parameters to be used to construct
%       the nsurf surfaces
% id = character string to identify which example is being run
% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% OUTPUT: 
% A .mat file with the name specified by the variable `id' is saved for
% you to call later using the function EvalKrigSurf.m.  No variable is
% output from the MakeKrigSurf.m function.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% set the number of training points to be used to construct the Krigifier
n = 500;

% collect a spacefilling x to be used to construct the Krigifier
x = lhsdesign(n,d,'criterion','maximin','iterations',3000);

% set the nugget size to be added to the correlation matrix when
% constucting the Krigifier
nug = 1e-6;

% initialize storage for MVN random draws and their corresponding
% correlation matrices
Y=NaN(n,nsurf);
R=NaN(n,n,nsurf);

% this is used to construct R below
[sj si]=meshgrid(1:n,1:n);
dsq=4*(x(sj,:)-x(si,:)).^2;

% for each desired surface, do the following
for jj=1:nsurf	
    
    % gather correlation parameters to be used for this surface
	rhodraw = rho(jj,:);
        
    % create correlation matrix R (using [sj si] and dsq calcs above)
	R(:,:,jj)=reshape(prod(bsxfun(@power,rhodraw,dsq),2),n,n)+nug*eye(n);

	% collect n training points used to construct the Krigifier
	Y(:,jj)=mvnrnd(mu*ones(1,n),R(:,:,jj)*sig2,1)';
	
	clear rhodraw

end
    
save(id)


end

